/**************** (c) 1998  SGS-Thomson Microelectronics **********************

PROJECT  : ST72311
COMPILER : ST7 HICROSS C (HIWARE)

MODULE  :  map72311.h
VERSION :  V 2.0

CREATION DATE :  27/03/98

AUTHOR : PPG 8-bit Micro Application Team 

-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

DESCRIPTION : ST72311 Hardware Register Mapping.

              This file contains the description of the hardware registers of
              the ST72311 microcontroller.
              
-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-

MODIFICATIONS :

******************************************************************************/


#ifndef MAP72311_H
#define MAP72311_H


/* ***************************************
   Peripherals Registers Definition
   *************************************** */
                                                                  
/* I/O ports registers */   
#pragma DATA_SEG SHORT PORT_A
extern    volatile unsigned char PADR;                /* port A data register             */          
extern    volatile unsigned char PADDR;               /* port A data direction register   */
extern    volatile unsigned char PAOR;                /* port A option register           */

#pragma DATA_SEG SHORT PORT_C
extern    volatile unsigned char PCDR;                /* port C data register             */          
extern    volatile unsigned char PCDDR;               /* port C data direction register   */
extern    volatile unsigned char PCOR;                /* port C option register           */

#pragma DATA_SEG SHORT PORT_B
extern    volatile unsigned char PBDR;                /* port B data register             */          
extern    volatile unsigned char PBDDR;               /* port B data direction register   */
extern    volatile unsigned char PBOR;                /* port B option register           */

#pragma DATA_SEG SHORT PORT_E
extern    volatile unsigned char PEDR;                /* port E data register             */          
extern    volatile unsigned char PEDDR;               /* port E data direction register   */
extern    volatile unsigned char PEOR;                /* port E option register           */

#pragma DATA_SEG SHORT PORT_D
extern    volatile unsigned char PDDR;                /* port D data register             */          
extern    volatile unsigned char PDDDR;               /* port D data direction register   */
extern    volatile unsigned char PDOR;                /* port D option register           */
  
#pragma DATA_SEG SHORT PORT_F
extern    volatile unsigned char PFDR;                /* port F data register             */          
extern    volatile unsigned char PFDDR;               /* port F data direction register   */
extern    volatile unsigned char PFOR;                /* port F option register           */
                                                                                                                                                           
/* Miscellaneous Register */                                                 
#pragma DATA_SEG SHORT MISC                                                  
extern    volatile unsigned char MISCR;               /* Miscellaneous register           */
   
/* Serial Peripheral Interface */                                            
#pragma DATA_SEG SHORT SPI
extern    volatile unsigned char SPIDR;               /* SPI Data Register                 */
extern    volatile unsigned char SPICR;               /* SPI Control Register              */
extern    volatile unsigned char SPISR;               /* SPI Status Register               */

/* Watchdog Register */                                                                        
#pragma DATA_SEG SHORT WDG                                                                     
extern    volatile unsigned char WDGCR;                /* Watchdog controlregister          */         
extern    volatile unsigned char WDGSR;                /* Watchdog status register          */
                            
/* Timer A */
#pragma DATA_SEG SHORT TIMERA
extern    volatile unsigned char TACR2;               /* timer A control register 2                 */
extern    volatile unsigned char TACR1;               /* timer A control register 1                 */
extern    volatile unsigned char TASR;                /* timer A status register                    */
extern    volatile unsigned char TAIC1HR;             /* timer A input capture 1 high register      */
extern    volatile unsigned char TAIC1LR;             /* timer A input capture 1 low register       */
extern    volatile unsigned char TAOC1HR;             /* timer A output compare 1 high register     */
extern    volatile unsigned char TAOC1LR;             /* timer A output compare 1 low register      */
extern    volatile unsigned char TACHR;               /* timer A counter high register              */
extern    volatile unsigned char TACLR;               /* timer A counter low register               */
extern    volatile unsigned char TAACHR;              /* timer A alternate counter high register    */
extern    volatile unsigned char TAACLR;              /* timer A alternate counter low register     */
extern    volatile unsigned char TAIC2HR;             /* timer A input capture 2 high register      */
extern    volatile unsigned char TAIC2LR;             /* timer A input capture 2 low register       */
extern    volatile unsigned char TAOC2HR;             /* timer A output compare 2 high register     */
extern    volatile unsigned char TAOC2LR;             /* timer A output compare 2 low register      */

/* Timer B */
#pragma DATA_SEG SHORT TIMERB
extern    volatile unsigned char TBCR2;               /* timer B control register 2                 */
extern    volatile unsigned char TBCR1;               /* timer B control register 1                 */
extern    volatile unsigned char TBSR;                /* timer B status register                    */
extern    volatile unsigned char TBIC1HR;             /* timer B input capture 1 high register      */
extern    volatile unsigned char TBIC1LR;             /* timer B input capture 1 low register       */
extern    volatile unsigned char TBOC1HR;             /* timer B output compare 1 high register     */
extern    volatile unsigned char TBOC1LR;             /* timer B output compare 1 low register      */
extern    volatile unsigned char TBCHR;               /* timer B counter high register              */
extern    volatile unsigned char TBCLR;               /* timer B counter low register               */
extern    volatile unsigned char TBACHR;              /* timer B alternate counter high register    */
extern    volatile unsigned char TBACLR;              /* timer B alternate counter low register     */
extern    volatile unsigned char TBIC2HR;             /* timer B input capture 2 high register      */
extern    volatile unsigned char TBIC2LR;             /* timer B input capture 2 low register       */
extern    volatile unsigned char TBOC2HR;             /* timer B output compare 2 high register     */
extern    volatile unsigned char TBOC2LR;             /* timer B output compare 2 low register      */

/* SCI Registers*/
#pragma DATA_SEG SHORT SCI
extern    volatile unsigned char SCISR;               /* SCI Status Register                         */
extern    volatile unsigned char SCIDR;               /* SCI Data Register                           */ 
extern    volatile unsigned char SCIBRR;              /* SCI Baud rate Register                      */
extern    volatile unsigned char SCICR1;              /* SCI Control Register 1                      */
extern    volatile unsigned char SCICR2;              /* SCI Control Register 2                      */
extern    volatile unsigned char SCIERPR;             /* SCI Extended receive prescaler register     */
extern    volatile unsigned char RESERV;              /* Reserved                                    */
extern    volatile unsigned char SCIETPR;             /* SCI Extended transmit prescaler register    */
 
/* Analog To Digital Converter */                                            
#pragma DATA_SEG SHORT ADC
extern    volatile unsigned char ADCDR;               /* ADC Data Register                 */
extern    volatile unsigned char ADCCSR;              /* ADC Control Status Register       */
                                                                  
#pragma DATA_SEG DEFAULT

/*****************************************************************************/
/***** H A R D W A R E   R E G I S T E R   B I T   D E F I N I T I O N S *****/
/*****************************************************************************/

/* General bit definition....................................................*/

#define ZERO        0x00
#define ONE         0x01
#define TWO         0x02
#define THREE       0x03
#define FOUR        0x04
#define FIVE        0x05
#define SIX         0x06
#define SEVEN       0x07
#define EIGHT       0x08
#define NINE        0x09
#define TEN         0x0A

/* SPI Control Register bit definition */

#define SPIE        0x07        // SPI interrupt enable
#define SPE         0x06        // SPI Output enable
#define MSTR        0x04        // SPI Master mode

/* SPI status register bit definition  */

#define SPIF        0x07        // SPI data transfer flag
#define WCOL        0x06        // SPI write collision status
#define MODF        0x04        // SPI mode fault Flag

/* Timers A&B Control Register 1 bit definition  */

#define ICIE        0x07        // Input capture interrupt enable                                    
#define OCIE        0x06        // Output compare interrupt enable                            
#define TOIE        0x05        // Timer overflow interrupt enable
#define OLVL2       0x02        // Output level 2
#define IEDG1       0x01        // Input edge 1
#define OLVL1       0x00        // Ouput level 1

/* Timers A&B Control Register 2 bit definition  */

#define OC1E        0x07        // Output compare 1 pin
#define OC2E        0x06        // Output compare 1 pin
#define OPM         0x05        // One pulse mode
#define PWM         0x04        // PWM Mode
#define IEDG2       0x01        // Input edge 2

/* Timer A&B Status register bit definition  */

#define ICF1        0x07        // Input capture 1 flag
#define OCF1        0x06        // Output compare 1 flag
#define TOF         0x05        // Timer overflow flag
#define ICF2        0x04        // Input capture 2 flag
#define OCF2        0x03        // Output compare 2 flag

/* SCI status register bit definition  */

#define TDRE        0x07        // Tansmit data register empty
#define TC          0x06        // Transmission complete
#define RDRF        0x05        // Received data ready flag
#define IDLE        0x04        // Idle line detect
#define _0R         0x03        // Overrun error
#define NF          0x02        // Noise flag
#define FE          0x01        // Framing error

/* SCI control register 1 bit definition */
#define R8          0x07        // Receive data bit8
#define T8          0x06        // Transmit data bit8
#define M           0x04        // Word lenght
#define WAKE        0x03        // Wake-up method

/* SCI control register 2 bit definition */
#define TIE         0x07        // Transmitter interrupt enable
#define TCIE        0x06        // Transmission complete interrupt enable
#define RIE         0x05        // Receiver interupt enable
#define ILIE        0x04        // Idle line interrupt enable
#define TE          0x03        // Transmitter enable
#define RE          0x02        // Receiver enable                         
#define RWU         0x01        // Receiver wake_up           
#define SBK         0x00        // Send break                  
 
// ADC Control/Status Register bit definition

#define COCO        0x07        // Conversion Complete
#define ADON        0x05        // A/D converter on

#endif

/*** (c) 1998  SGS-Thomson Microelectronics ****************** END OF FILE *****/
